cost_factory
===============================================

.. currentmodule:: skchange.costs

.. autofunction:: cost_factory

.. include:: skchange.costs.cost_factory.examples

.. raw:: html

    <div class="clearer"></div>